==> haskell-reducers-3.12.1-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.1
id: reducers-3.12.1-9uKoIuzwjOq4bV8xdeZLeo
key: reducers-3.12.1-9uKoIuzwjOq4bV8xdeZLeo
license: BSD3
copyright: Copyright (C) 2008-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Generator
    Data.Semigroup.Reducer Data.Semigroup.Reducer.With
    Data.Semigroup.Instances Data.Semigroup.Union Data.Semigroup.Apply
    Data.Semigroup.Applicative Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Self
abi: 6d9e9cfaa85dfee189f1b54750c8774c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/reducers-3.12.1
hs-libraries: HSreducers-3.12.1-9uKoIuzwjOq4bV8xdeZLeo
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    semigroupoids-5.1-Aosck6aPap49jKxY1m28VE
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.1-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.1
id: reducers-3.12.1-9jTmYEjFOosI30Qzbf0mZf
key: reducers-3.12.1-9jTmYEjFOosI30Qzbf0mZf
license: BSD3
copyright: Copyright (C) 2008-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Generator
    Data.Semigroup.Reducer Data.Semigroup.Reducer.With
    Data.Semigroup.Instances Data.Semigroup.Union Data.Semigroup.Apply
    Data.Semigroup.Applicative Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Self
abi: 17bcf04df199760d5f78f47deb7d8476
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/reducers-3.12.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/reducers-3.12.1
hs-libraries: HSreducers-3.12.1-9jTmYEjFOosI30Qzbf0mZf
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    fingertree-0.1.1.0-C6YFXKIQXOA6HvmvFT5gT9
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    semigroupoids-5.1-mvlh42rhjC5vNXakyMT7n
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
